### Name: pvcovHC
### Title: Robust covariance matrix estimators
### Aliases: pvcovHC
### Keywords: regression

### ** Examples

library(lmtest)
library(car)
library(Ecdat)
library(plm)
data(Produc)
Produc <-pdata.frame(Produc,"state","year")
zz <- plm(log(gsp)~log(pcap)+log(pc)+log(emp)+unemp,data=Produc,model="random")
## standard coefficient significance test
coeftest(zz)
## robust significance test
coeftest(zz, vcov=pvcovHC)
## idem with parameters, pass vcov as a function argument
coeftest(zz, vcov=function(x) pvcovHC(x, type="arellano", weights="HC1"))
## idem with parameters, pass vcov as a matrix argument
coeftest(zz, vcov=pvcovHC(zz, type="arellano", weights="HC1"))
## joint restriction test
waldtest(zz, update(zz, .~.-log(emp)-unemp), vcov=pvcovHC)
## test of hyp.: 2*log(pc)=log(emp)
linear.hypothesis(zz, "2*log(pc)=log(emp)", vcov=pvcovHC)




